# Personal Capital

Python library for accessing Personal Capital data

# Installation

## With Pip

`pip install personal-capital-plus`

## With Source Code

You can get the source code by cloning it from Github:

`git clone https://github.com/aagnone/personalcapital.git`

or get the tarball:

`curl -OJL https://github.com/aagnone/personalcapital/tarball/master`

then either include the library into your code, or install it with:

`python setup.py install`

# Usage
TODO

# Personal Capital API

Please inspect the network requests to see what requests are possible. The `main.py` example includes two such calls.
